Module bearings

Module bearings 

Enums

Bearing

Functions

bearing_to_point
Returns the bearing direction from the viewport center to point, but only if the point is off-screen.
bearings_for_anchors
Bearings for all experience-visible anchor nodes that are off-screen. Returns (NodeId, Bearing).
bearings_for_visible_nodes
Bearings for all experience-visible nodes that are off-screen. Returns (NodeId, Bearing).