Module cluster
halley_
core
0.2.0
Module cluster
Module Items
Structs
Enums
In crate halley_
core
halley_core
Module
cluster
Structs

Active
Workspace
Cluster
A cluster is a group of window nodes (members). When collapsed, a Core node represents the cluster as the handle.
Cluster
Id
Enums

Cluster
Mode
Cluster
Remove
Member
Outcome