pub struct Focus { /* private fields */ }Expand description
Current interaction target (separate from history). Focus only applies to nodes that are present and experience-visible.
Implementations
Sourceimpl Focus
impl Focus
pub fn new() -> Self
pub fn current(&self) -> Option<NodeId>
pub fn is_focused(&self, id: NodeId) -> bool
Sourcepub fn set(&mut self, field: &Field, id: NodeId) -> bool
pub fn set(&mut self, field: &Field, id: NodeId) -> bool
Set focus to id if it exists and is experience-visible.
pub fn clear(&mut self)
Sourcepub fn on_removed(&mut self, removed: NodeId)
pub fn on_removed(&mut self, removed: NodeId)
If the focused node is removed, clear focus.
If the focused node becomes hidden (collapse/hide/detach), clear focus.