Focus

Struct Focus 

pub struct Focus { /* private fields */ }
Current interaction target (separate from history). Focus only applies to nodes that are present and experience-visible.

Implementations

Source

impl Focus

pub fn new() -> Self

pub fn current(&self) -> Option<NodeId>

pub fn is_focused(&self, id: NodeId) -> bool

pub fn set(&mut self, field: &Field, id: NodeId) -> bool

Set focus to id if it exists and is experience-visible.

pub fn clear(&mut self)

pub fn on_removed(&mut self, removed: NodeId)

If the focused node is removed, clear focus.

pub fn on_hidden(&mut self, field: &Field, id: NodeId)

If the focused node becomes hidden (collapse/hide/detach), clear focus.